%define major   0
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:           hivex
Version:        1.3.13
Release:        %mkrel 3
Summary:        Read and write Windows Registry binary hive files

Group:          File tools
License:        LGPLv2
URL:            http://libguestfs.org/
Source0:        http://libguestfs.org/download/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  gettext-devel
BuildRequires:  perl-devel
BuildRequires:  perl-Test-Simple
BuildRequires:  perl-Test-Pod
BuildRequires:  perl-Test-Pod-Coverage
BuildRequires:  perl-IO-stringy
BuildRequires:  perl-libintl-perl
BuildRequires:  ocaml
BuildRequires:  ocaml-findlib
BuildRequires:  ruby-devel
BuildRequires:  ruby-rake
BuildRequires:  ruby-minitest
BuildRequires:  ruby-test-unit
BuildRequires:  readline-devel
BuildRequires:  libxml2-devel

%description
Hive files are the undocumented binary blobs that Windows uses to
store the Windows Registry on disk.  Hivex is a library that can read
and write to these files.

'hivexsh' is a shell you can use to interactively navigate a hive
binary file.

'hivexregedit' lets you export and merge to the textual regedit
format.

'hivexml' can be used to convert a hive file to a more useful XML
format.

In order to get access to the hive files themselves, you can copy them
from a Windows machine.  They are usually found in
%%systemroot%%\system32\config.  For virtual machines we recommend
using libguestfs or guestfish to copy out these files.  libguestfs
also provides a useful high-level tool called 'virt-win-reg' (based on
hivex technology) which can be used to query specific registry keys in
an existing Windows VM.

For Perl bindings, see 'perl-hivex'.

For OCaml bindings, see 'ocaml-hivex-devel'.

For Ruby bindings, see 'ruby-hivex'.


%package -n %{libname}
Summary:        Shared libraries for %{name}
Group:          System/Libraries
Conflicts:      %{name} < 1.3.8-5

%description -n %{libname}
This package contains the shared libraries for %{name}.

%package -n %{devname}
Summary:        Development tools and libraries for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < 1.3.8-5

%description -n %{devname}
This package contains development tools and libraries
for %{name}.


%package -n ocaml-%{name}
Summary:       OCaml bindings for %{name}
Group:         Development/OCaml


%description -n ocaml-%{name}
ocaml-%{name} contains OCaml bindings for %{name}.

This is for toplevel and scripting access only.  To compile OCaml
programs which use %{name} you will also need ocaml-%{name}-devel.


%package -n ocaml-%{name}-devel
Summary:       OCaml bindings for %{name}
Group:         Development/OCaml
Requires:      ocaml-%{name} = %{version}-%{release}
Requires:      %{devname} = %{version}-%{release}


%description -n ocaml-%{name}-devel
ocaml-%{name}-devel contains development libraries
required to use the OCaml bindings for %{name}.


%package -n perl-%{name}
Summary:       Perl bindings for %{name}
Group:         Development/Perl


%description -n perl-%{name}
perl-%{name} contains Perl bindings for %{name}.


%package -n ruby-%{name}
Summary:       Ruby bindings for %{name}
Group:         Development/Ruby
Provides:      ruby(hivex) = %{version}

%description -n ruby-%{name}
ruby-%{name} contains Ruby bindings for %{name}.

%prep
%setup -q
%autopatch -p1

%build
#update autotool files
autoreconf -vfi

%configure2_5x --disable-static PYTHON=no
make

%check
make check

%install
%make_install

# we don't want these
find %{buildroot} -name "*.la" -delete

# fix rights
chmod +w %{buildroot}%{perl_sitearch}/auto/Win/Hivex/Hivex.so

# Remove unwanted Perl files:
find %{buildroot} -name perllocal.pod -delete
find %{buildroot} -name .packlist -delete
find %{buildroot} -name '*.bs' -delete
mkdir -p %{buildroot}%{_mandir}/man3
mv %{buildroot}/usr/local/share/man/man3/*.3pm %{buildroot}%{_mandir}/man3/


%find_lang %{name}

%files -f %{name}.lang
%doc README LICENSE
%{_bindir}/hivexget
%{_bindir}/hivexml
%{_bindir}/hivexregedit
%{_bindir}/hivexsh
%{_mandir}/man1/hivexget.1*
%{_mandir}/man1/hivexml.1*
%{_mandir}/man1/hivexregedit.1*
%{_mandir}/man1/hivexsh.1*

%files -n %{libname}
%{_libdir}/libhivex.so.%{major}
%{_libdir}/libhivex.so.%{major}.*

%files -n %{devname}
%doc LICENSE
%{_libdir}/libhivex.so
%{_mandir}/man3/hivex.3*
%{_includedir}/hivex.h
%{_libdir}/pkgconfig/hivex.pc

%files -n ocaml-%{name}
%doc README
%{_libdir}/ocaml/hivex
%exclude %{_libdir}/ocaml/hivex/*.a
%exclude %{_libdir}/ocaml/hivex/*.cmxa
%exclude %{_libdir}/ocaml/hivex/*.cmx
%exclude %{_libdir}/ocaml/hivex/*.mli
%{_libdir}/ocaml/stublibs/*.so
%{_libdir}/ocaml/stublibs/*.so.owner


%files -n ocaml-%{name}-devel
%{_libdir}/ocaml/hivex/*.a
%{_libdir}/ocaml/hivex/*.cmxa
%{_libdir}/ocaml/hivex/*.cmx
%{_libdir}/ocaml/hivex/*.mli


%files -n perl-%{name}
%{_mandir}/man3/*
%{perl_sitearch}/*


%files -n ruby-%{name}
%doc ruby/doc/site/*
%{ruby_sitelibdir}/hivex.rb
%{ruby_sitearchdir}/_hivex.so


%changelog
* Sun Sep 25 2016 pterjan <pterjan> 1.3.13-3.mga6
+ Revision: 1056211
- Rebuild for fix in ocaml

* Sat Jun 18 2016 pterjan <pterjan> 1.3.13-2.mga6
+ Revision: 1022149
- Rebuild for perl 5.22.2

* Thu Mar 24 2016 daviddavid <daviddavid> 1.3.13-1.mga6
+ Revision: 994749
- new version: 1.3.13
- remove merged upstream patches
- add missing BR on ruby-minitest needed for testsuite

* Wed Feb 10 2016 pterjan <pterjan> 1.3.8-13.mga6
+ Revision: 953009
- Rebuild for new ocaml

* Wed Nov 11 2015 daviddavid <daviddavid> 1.3.8-12.mga6
+ Revision: 902018
- rebuild for new ruby 2.2.3

* Mon Jul 27 2015 sander85 <sander85> 1.3.8-11.mga6
+ Revision: 858247
- Drop BR on perl-ExtUtils-MakeMaker-Coverage

* Thu Jun 25 2015 tv <tv> 1.3.8-10.mga6
+ Revision: 843532
- rebuild with soname-ified perl

* Tue Jun 23 2015 tv <tv> 1.3.8-9.mga6
+ Revision: 841186
- rebuild for perl-5.22

* Tue Dec 09 2014 luigiwalser <luigiwalser> 1.3.8-8.mga5
+ Revision: 802375
- add patches from fedora to fix handling of invalid hive files (CVE-2014-9273)

* Wed Oct 15 2014 umeabot <umeabot> 1.3.8-7.mga5
+ Revision: 748256
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.3.8-6.mga5
+ Revision: 680156
- Mageia 5 Mass Rebuild

* Fri Aug 08 2014 wally <wally> 1.3.8-5.mga5
+ Revision: 661083
- fix libification

* Tue Jun 03 2014 jquelin <jquelin> 1.3.8-4.mga5
+ Revision: 632356
- perl 5.20.0 rebuild

* Tue Jun 03 2014 pterjan <pterjan> 1.3.8-3.mga5
+ Revision: 632299
- Rebuild for perl 5.20

* Tue Oct 22 2013 umeabot <umeabot> 1.3.8-2.mga4
+ Revision: 543425
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 malo <malo> 1.3.8-1.mga4
+ Revision: 498713
- new version 1.3.8

* Sat Sep 21 2013 fwang <fwang> 1.3.7-7.mga4
+ Revision: 482942
- rebuild for ruby 2.0

* Thu Jun 20 2013 fwang <fwang> 1.3.7-6.mga4
+ Revision: 445195
- use ruby-test-unit
- try build with ruby-minitest
- add debian patch to have it build with latest ruby

* Wed May 29 2013 fwang <fwang> 1.3.7-5.mga4
+ Revision: 430396
- rebuild for new perl

* Fri Feb 08 2013 fwang <fwang> 1.3.7-4.mga3
+ Revision: 396861
- rebuild for new rdoc

* Sat Jan 12 2013 umeabot <umeabot> 1.3.7-3.mga3
+ Revision: 353273
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 02 2012 fwang <fwang> 1.3.7-2.mga3
+ Revision: 312423
- update file list
- br minitest for check
- rebuild for new ruby

* Wed Oct 24 2012 malo <malo> 1.3.7-1.mga3
+ Revision: 309754
- update RPM group
- update to 1.3.7

* Thu Jun 14 2012 malo <malo> 1.3.6-1.mga3
+ Revision: 260672
- update to 1.3.6

* Thu May 31 2012 fwang <fwang> 1.3.3-4.mga3
+ Revision: 251944
- rebuild for new perl

  + jquelin <jquelin>
    - perl 5.16 rebuild
    - perl 5.16 rebuild

* Wed Mar 07 2012 malo <malo> 1.3.3-1.mga2
+ Revision: 220694
- new version 1.3.3

* Thu Nov 17 2011 malo <malo> 1.3.2-1.mga2
+ Revision: 168368
- patch from Fedora to fix autoconf
- fix BuildRequires
- fix Source URL
- new version 1.3.2
- added patches from Fedora (allows to build correctly)
- enable Ruby bindings
- spec clean up

* Sun Jun 12 2011 sander85 <sander85> 1.2.2-3.mga2
+ Revision: 104652
- Rebuild for perl 5.14

* Thu Mar 24 2011 boklm <boklm> 1.2.2-2.mga1
+ Revision: 76154
- rebuild for bug #497

* Mon Mar 21 2011 saispo <saispo> 1.2.2-1.mga1
+ Revision: 75279
- imported package hivex

